#!/usr/bin/env python3
# Author: Zhang Yunjun, Jan 2021
# Copyright 2020, by the California Institute of Technology.


import collections
import os
import subprocess


###########################################################################
# release history
Tag = collections.namedtuple('Tag', 'version date')
release_history = (
    Tag('0.2.3', '2022-10-23'),
    Tag('0.2.2', '2022-07-20'),
    Tag('0.2.1', '2022-01-05'),
    Tag('0.2.0', '2021-11-10'),
    Tag('0.1.2', '2021-02-24'),
    Tag('0.1.1', '2021-02-01'),
    Tag('0.1.0', '2021-01-22'),
)

# latest release
release_version = release_history[0].version
release_date = release_history[0].date

# get development version info
def get_version_info():
    """Grab version and date of the latest commit from a git repository"""
    # go to the repository directory
    dir_orig = os.getcwd()
    os.chdir(os.path.dirname(os.path.dirname(__file__)))

    try:
        # grab from git cmd
        cmd = "git describe --tags"
        version = subprocess.check_output(cmd.split(), stderr=subprocess.DEVNULL)
        version = version.decode('utf-8').strip()[1:]

        # if there are new commits after the latest release
        if '-' in version:
            version, num_commit = version.split('-')[:2]
            version += f'-{num_commit}'

        cmd = "git log -1 --date=short --format=%cd"
        date = subprocess.check_output(cmd.split(), stderr=subprocess.DEVNULL)
        date = date.decode('utf-8').strip()

    except:
        # use the latest release version/date
        version = release_version
        date = release_date

    # go back to the original directory
    os.chdir(dir_orig)
    return version, date


###########################################################################
version, version_date = get_version_info()




# Author: Zhang Yunjun, Jan 2021
# Copyright 2020, by the California Institute of Technology.
# Note by Yunjun, Oct 2022: "pip install pysolid" does not work,
#   because a Fortran compiler is required but not available via pip


import os
import sys

# always prefer setuptools over distutils
import setuptools
from numpy.distutils.core import setup, Extension

# Grab from pysolid.version: version
# link: https://stackoverflow.com/questions/53648900
sys.path.append(os.path.join(os.path.dirname(__file__), 'src'))
from pysolid.version import version

# Grab from README file: long_description
with open("README.md", "r") as f:
    long_description = f.read()

setup(
    name='pysolid',
    version=version,
    description="A Python wrapper for solid to compute solid Earth tides",
    url="https://github.com/insarlab/PySolid",
    download_url=("https://github.com/insarlab/PySolid/archive/v{}.tar.gz".format(version)),
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Zhang Yunjun, Dennis Milbert",
    author_email="yunjunzgeo@gmail.com",
    license="GPL-3.0-or-later",
    license_files=("LICENSE",),

    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Science/Research",
        "Topic :: Scientific/Engineering",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
    ],
    keywords="solid Eartth tides, deformation, geodesy, geophysics",

    project_urls={
        "Bug Reports": "https://github.com/insarlab/PySolid/issues",
        "Source": "https://github.com/insarlab/PySolid",
    },

    # package discovery
    packages=setuptools.find_packages("src"),  # include all packages under src
    package_dir={"": "src"},                   # tell distutils packages are under src

    # build fortran deps with numpy.f2py
    ext_modules=[
        Extension(name='pysolid.solid', sources=['src/pysolid/solid.for']),
    ],

    # dependencies
    python_requires=">=3.6",
    install_requires=[
        'numpy',
        'scipy',
        'matplotlib',
        'scikit-image',
    ],

    # data files
    include_package_data=True,
    package_data={
        "pysolid": ["solid.for"],
    },
)



# get version info
from pysolid.version import version as __version__

# top-level functions
from pysolid.grid import (
    calc_solid_earth_tides_grid,
    plot_solid_earth_tides_grid,
)
from pysolid.point import (
    TIDES,
    calc_solid_earth_tides_point,
    plot_solid_earth_tides_point,
    plot_power_spectral_density4tides,
)
